"""A python package to stor and manipulate gravitational-wava data
in a conveninet framework.
Part of its classes and methods have been taken from GwPy, by D.McLeod
"""

# set package metadata
__version__ = "0.3.0"



"""

 Script name: gwLogger.py

 Description:
    This class contains a custom logger

"""

import logging
import time
import sys
import os

# Now, some additional information

__author__ = "Massimiliano Razzano"
__copyright__ = "Copyright 2016-2020, Massimiliano Razzano"
__credits__ = ["Line for credits"]
__license__ = "GPL"
__version__ = "1.0.0"
__maintainer__ = "M. Razzano"
__email__ = "massimiliano.razzano@unipi.it"
__status__ = "Production"


class GWLogger(logging.Logger):
    """

    This class contains a custom logger

    """

    def __init__(self, name, m_loglevel="INFO",m_file_logging=False,m_log_dir=None):
        # init start time
        self.__name = name
        self.__log_filename = None
        self.__log_dir = m_log_dir
        self.__start_time = str(time.strftime("%y%m%d_%Hh%Mm%Ss", time.localtime()))

        logging.Logger.__init__(self, name)

        base_handler = logging.StreamHandler(sys.stdout)
        base_handler.setLevel(logging.DEBUG)

        formatter = logging.Formatter('%(asctime)s %(levelname)-4s: %(message)s', datefmt='%H:%M:%S')

        base_handler.setFormatter(formatter)
        self.addHandler(base_handler)

        if m_file_logging:
            if not os.path.exists(m_log_dir):
                os.mkdir(m_log_dir)

            #add a file logger
            if m_log_dir is None:
                file_handler_name = self.__name+"_"+self.__start_time+".log"
            else:
                file_handler_name = os.path.join(m_log_dir,self.__name+"_"+self.__start_time+".log")

            try:
                file_handler = logging.FileHandler(file_handler_name)
                self.__log_filename = file_handler_name
                self.addHandler(file_handler)
            except OSError:
                self.error("Cannot open the log file")


        self.set_loglevel(m_loglevel=m_loglevel)

        if m_file_logging:
            self.info("Log file saved to "+file_handler_name)

        self.info('Logger started at ' + self.__start_time + " (LEVEL=" + str(self.getEffectiveLevel()) + ")")

        #self.__stdout_logger = logging.getLogger('STDOUT')
        #self.__sl = StreamToLogger(self.__stdout_logger, logging.INFO)
        #sys.stdout =self.__sl

    def get_log_filename(self):
        """

        :return:
        """

        return self.__log_filename


    def set_loglevel(self,m_loglevel):
        """

        :param m_loglevel:
        :return:

        """

        if m_loglevel=="DEBUG":
            self.setLevel(logging.DEBUG)
        if m_loglevel == "INFO":
            self.setLevel(logging.INFO)

        self.info("Logging level set to "+m_loglevel)


if __name__ == '__main__':
    print("\n****\nTesting Logger...\n****\n")

    my_logger = GWLogger("testlogger")
    my_logger.setLevel(logging.DEBUG)
    my_logger.debug("This is a debug message")

    my_logger.setLevel(logging.INFO)
    my_logger.debug("This is an info message")

    my_logger.setLevel(logging.ERROR)
    my_logger.debug("...and this is an ERROR message!")



"""Setup the gwdama package
"""

try:
    from setuptools import setup, find_packages
    pkgs = find_packages(exclude=("tests",))
except ImportError:
    from distutils.core import setup
    pkgs = ['gwdama', 'gwdama.io', 'gwdama.plot']

# read description
with open("README.rst", "r") as fh:
    long_description = fh.read()

# runtime dependencies
install_requires = [
    'gwdatafind',
    'gwosc==0.5.3',
    'gwpy==1.0.1',
    'h5py==2.10.0',
    'lalsuite>=6.73',
    'matplotlib>=3.2.2',
    'numpy== 1.19.0',
    'pandas==1.0.5',
    'python-dateutil',
    'scikit-learn==0.23.1',
    'scipy==1.5.1',
    'six >= 1.5',
]
    
setup_kwargs = {
    'name': "gwdama",
    'version': "0.3.0",
    'author': "Pisa Detchar Group",
    'author_email': "francesco.direnzo@df.unipi.it",
    'description': "A GW data manager package and more",
    'long_description': long_description,
    'long_description_content_type': "text/x-rst",
    'url': 'https://gwdama.readthedocs.io/en/latest/index.html',
    'download_url': 'https://gitlab.com/gwprojects/gwdama',
    'packages': pkgs,
    'classifiers': [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    'python_requires': '>=3.6',
    'install_requires' : install_requires,
    'include_package_data' : True,
}

if __name__ == '__main__':
    # This call to setup() does all the work
    setup(**setup_kwargs)
